@@ -347,7 +347,7 @@ class GA():
                 
             
         '''
-        y =  x + 10*sin(5*x) + 7*cos(4*x)
+        y =  x + 10*mh.sin(5*x) + 7*mh.cos(4*x)
         return y
 
     def decode(self,chro, limit = [0,10]):
@@ -675,8 +675,8 @@ class Shuffled_Frog_Leaping_Algorithm():
                 e_1 = []    
                 for j in self.lotus_colony[i]:
                     e_1.append(j.y)
-                min_one = self.lotus_colony[i][argmin(e_1)] 
-                max_one = self.lotus_colony[i][argmax(e_1)] 
+                min_one = self.lotus_colony[i][np.argmin(e_1)] 
+                max_one = self.lotus_colony[i][np.argmax(e_1)] 
                 #Step 3: 计算计划位移至的位置x,以及对应的评价值
                 x_1 = min_one.x + rand.random()*(max_one.x-min_one.x)
                 y_1 = min_one.evaluate(x_1)
@@ -689,7 +689,7 @@ class Shuffled_Frog_Leaping_Algorithm():
                     e_2 = []    
                     for j in self.lotus_colony[0]:
                         e_2.append(j.y)
-                    max_abs_one = self.lotus_colony[0][argmax(e_2)] 
+                    max_abs_one = self.lotus_colony[0][np.argmax(e_2)] 
                     #Step 6: 计算计划位移至的位置x,以及对应的评价值
                     x_1 = min_one.x + rand.random()*(max_abs_one.x-min_one.x)
                     y_1 = min_one.evaluate(x_1)
@@ -709,7 +709,7 @@ class Shuffled_Frog_Leaping_Algorithm():
                 e_1 = []    
                 for j in self.lotus_colony[i]:
                     e_1.append(j.y)
-                x_1 = argmax(e_1)
+                x_1 = np.argmax(e_1)
                 x.append(x_1)
                 if self.lotus_colony[i][x_1].y>=max_num:
                     y = k
@@ -802,15 +802,15 @@ class WOA():
             self.plot_ave.append(sum(fitness)/len(fitness))
             self.plot_min.append(self.best_fitness)
             #Step 5: 打印坐标看看(自增加过程，可删)
-            plt.clf()
-            plt.plot(self.x[:,0],self.x[:,1],'o',color = 'black')
-            plt.title('Round:'+str(i))
-            plt.xlim([0,6])
-            plt.ylim([0,6])
-            plt.show(block = False)
-            plt.pause(0.1)
-        else:
-            plt.show()
+        #     plt.clf()
+        #     plt.plot(self.x[:,0],self.x[:,1],'o',color = 'black')
+        #     plt.title('Round:'+str(i))
+        #     plt.xlim([0,6])
+        #     plt.ylim([0,6])
+        #     plt.show(block = False)
+        #     plt.pause(0.1)
+        # else:
+        #     plt.show()
 
 
 
@@ -867,15 +867,15 @@ class PSO():
             print('第{%d}代，ave:{%f}, max:{%f}'%(i,sum(fitness)/len(fitness),self.best_abs_fit))
             self.plot_ave.append(sum(fitness)/len(fitness))
             self.plot_max.append(self.best_abs_fit)
-            plt.clf()
-            plt.plot(self.x[:,0],self.x[:,1],'o',color='black')
-            plt.xlim((0,6))
-            plt.ylim((0,6))
-            plt.title('Round '+str(i))
-            plt.show(block = False)
-            plt.pause(0.1)
-        else:
-            plt.show()
+        #     plt.clf()
+        #     plt.plot(self.x[:,0],self.x[:,1],'o',color='black')
+        #     plt.xlim((0,6))
+        #     plt.ylim((0,6))
+        #     plt.title('Round '+str(i))
+        #     plt.show(block = False)
+        #     plt.pause(0.1)
+        # else:
+        #     plt.show()
 
 class PSO_min():
     '''
@@ -926,12 +926,12 @@ class PSO_min():
                 self.best_abs = self.x[np.argmin(fitness)].copy()
                 #print('更新后:',self.best_abs,':',self.evaluate(np.array([self.best_abs])))
             print('第{%d}代，ave:{%f}, max:{%f}'%(i,sum(fitness)/len(fitness),self.best_abs_fit))
-            plt.clf()
-            plt.plot(self.x[:,0],self.x[:,1],'o',color='black')
-            plt.xlim((-10,10))
-            plt.ylim((-10,10))
-            plt.show(block = False)
-            plt.pause(0.1)
+            # plt.clf()
+            # plt.plot(self.x[:,0],self.x[:,1],'o',color='black')
+            # plt.xlim((-10,10))
+            # plt.ylim((-10,10))
+            # plt.show(block = False)
+            # plt.pause(0.1)
             
 
 
